Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/nextcloud/server.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
path: root/build
diff options
context:
space:
mode:
authorJoas Schilling <coding@schilljs.com>2021-06-24 14:12:52 +0300
committerDaniel Calviño Sánchez <danxuliu@gmail.com>2021-11-15 08:58:05 +0300
commit49486de8cd746d20497bf56b5054720888ccff0e (patch)
tree6d2fb34c71026db1f0a7b33cec6a26d89b037474 /build
parent6db690c3c79de1045ee8497af659c61e2784a532 (diff)
Fix branch selection in stable23
Signed-off-by: Joas Schilling <coding@schilljs.com>
Diffstat (limited to 'build')
-rwxr-xr-xbuild/update-apps.sh8
-rwxr-xr-xbuild/update.sh6
2 files changed, 7 insertions, 7 deletions
diff --git a/build/update-apps.sh b/build/update-apps.sh
index e4611a79aff..db9330143ae 100755
--- a/build/update-apps.sh
+++ b/build/update-apps.sh
@@ -1,14 +1,14 @@
#!/bin/bash
# Update Nextcloud apps from latest git master
# For local development environment
# Use from Nextcloud server folder with `./build/update-apps.sh`
#
# It automatically:
# - goes through all apps which are not shipped via server
# - shows the app name in bold and uses whitespace for separation
# - changes to master and pulls quietly
# - shows the 3 most recent commits for context
# - removes branches merged into master
# - … could even do the build steps if they are consistent for the apps (like `make`)
-find apps* -maxdepth 2 -name .git -exec sh -c 'cd {}/../ && printf "\n\033[1m${PWD##*/}\033[0m\n" && git checkout master && git pull --quiet -p && git --no-pager log -3 --pretty=format:"%h %Cblue%ar%x09%an %Creset%s" && printf "\n" && git branch --merged master | grep -v "master$" | xargs git branch -d && cd ..' \;
+find apps* -maxdepth 2 -name .git -exec sh -c 'cd {}/../ && printf "\n\033[1m${PWD##*/}\033[0m\n" && git checkout stable23 && git pull --quiet -p && git --no-pager log -3 --pretty=format:"%h %Cblue%ar%x09%an %Creset%s" && printf "\n" && git branch --merged stable23 | grep -v "stable23$" | xargs git branch -d && cd ..' \;
@@ -1,14 +1,14 @@
#!/bin/bash
-# Update Nextcloud apps from latest git master
+# Update Nextcloud apps from latest git stable23
# For local development environment
# Use from Nextcloud server folder with `./build/update-apps.sh`
@@ -1,14 +1,14 @@
# - goes through all apps which are not shipped via server
# - shows the app name in bold and uses whitespace for separation
-# - changes to master and pulls quietly
+# - changes to stable23 and pulls quietly
# - shows the 3 most recent commits for context
@@ -1,14 +1,14 @@
# - shows the 3 most recent commits for context
-# - removes branches merged into master
+# - removes branches merged into stable23
# - … could even do the build steps if they are consistent for the apps (like `make`)
diff --git a/build/update.sh b/build/update.sh
index 3a3d2eac5dc..ba7fd9c01b8 100755
--- a/build/update.sh
+++ b/build/update.sh
@@ -1,15 +1,15 @@
#!/bin/bash
# Update Nextcloud server and apps from latest git master
# For local development environment
# Use from Nextcloud server folder with `./build/update.sh`
# Update server
printf "\n\033[1m${PWD##*/}\033[0m\n"
-git checkout master
+git checkout stable23
git pull --quiet -p
git --no-pager log -3 --pretty=format:"%h %Cblue%ar%x09%an %Creset%s"
printf "\n"
-git branch --merged master | grep -v "master$" | xargs git branch -d
+git branch --merged stable23 | grep -v "stable23$" | xargs git branch -d
git submodule update --init
# Update apps
@@ -1,15 +1,15 @@
#!/bin/bash
-# Update Nextcloud server and apps from latest git master
+# Update Nextcloud server and apps from latest git stable23
# For local development environment
# Use from Nextcloud server folder with `./build/update.sh`